Registration
============

To start using a matridge instance, you need to create an account by
registering with it. The instance has a unique XMPP (aka JID) address, which is
usually just a domain name (e.g., "matrix.example.org"), without a
username or local part.

There are two ways to register, depending on your client:

- If your client supports adhoc commands (such as Movim, Gajim, or Cheogram),
  you can use the "Register" command with the matridge instance's
  address.
- If your client does not support adhoc commands (such as Conversations), you
  can register by sending a text message that says "register" to the
  matridge instance's address.
